# vim: set ts=4 sw=4 et:
# Copyright (c) 2012 Pascal Bleser <pascal.bleser@opensuse.org>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/


%define		libname		libmpdclient
%define		soname		2

Name:           libmpdclient
Version:        2.10
Release:        1.13
License:        GPL-3.0+
Summary:        Library to control the Music Player Daemon
Url:            http://www.musicpd.org/
Group:          Productivity/Multimedia/Sound/Players
Source0:        http://www.musicpd.org/download/libmpdclient/2/libmpdclient-%{version}.tar.xz
BuildRequires:  doxygen
BuildRequires:  pkgconfig
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
A stable, documented, asynchronous API library for interfacing MPD in the C,
C++ & Objective C languages.

%package -n libmpdclient%{soname}
Summary:        Library to control the Music Player Daemon
Group:          System/Libraries

%description -n libmpdclient%{soname}
A stable, documented, asynchronous API library for interfacing MPD in the C,
C++ & Objective C languages.

%package -n libmpdclient-devel
Summary:        Development package for libmpdclient
Group:          Development/Libraries/C and C++
Requires:       libmpdclient%{soname} = %{version}

%description -n libmpdclient-devel
A stable, documented, asynchronous API library for interfacing MPD in the C,                                            
C++ & Objective C languages.

Development package for %{name}.

%prep
%setup -q 

%build
%configure \
    --enable-debug \
    --disable-static

make %{?_smp_flags}

%install
%makeinstall
rm %{buildroot}/%{_libdir}/*.la

%post   -n libmpdclient%{soname} -p /sbin/ldconfig
%postun -n libmpdclient%{soname} -p /sbin/ldconfig

%clean
%{?buildroot:%__rm -rf "%{buildroot}"}

%files -n libmpdclient%{soname}
%defattr(-,root,root)
%{_libdir}/libmpdclient.so.%{soname}
%{_libdir}/libmpdclient.so.%{soname}.*

%files -n libmpdclient-devel
%defattr(-,root,root)
%dir %{_includedir}/mpd
%{_includedir}/mpd/*.h
%{_libdir}/libmpdclient.so
%{_libdir}/pkgconfig/libmpdclient.pc
%dir %{_datadir}/vala
%dir %{_datadir}/vala/vapi
%{_datadir}/vala/vapi/libmpdclient.vapi
%doc %dir %{_datadir}/doc/libmpdclient
%doc %{_datadir}/doc/libmpdclient/*

%changelog
* Thu Aug 27 2015 Mathias.Homann@opensuse.org
- Update to 2.10
  libmpdclient 2.10 (2015/02/23)
  * support abstract sockets with "@" prefix
  * support tag "MUSICBRAINZ_RELEASETRACKID"
  * add TCP keepalive internal and external APIs
  * support MPD protocol 0.19
  - status: support sample formats "float" and "dsd"
  - song: report duration with milliseconds precision
  - search: support constraint "modified-since"
  * support MPD protocol 0.20
  - the "window" parameter for commands "find"/"search"
* Mon Feb 10 2014 pascal.bleser@opensuse.org
- update to 2.9:
  * directory: support attribute "Last-Modified"
  * support MPD protocol 0.18
  - command "readcomments"
  - command "toggleoutput"
  - command "volume"
  - the "base" constraint for commands "find"/"search"
* Tue Jun 18 2013 fisiu@opensuse.org
- Update to 2.8:
  * song: support attribute "Prio"
  * queue: fix the ranged "prio" command
  * queue: support open ranges
* Mon Feb  6 2012 pascal.bleser@opensuse.org
- update to 2.7:
* Tue Nov  1 2011 detlef@links2linux.de
- new upstream version <2.6>
  * mpd/client.h: include message.h
  * queue: support song priorities
* Sat Jul 23 2011 detlef@links2linux.de
- new upstream version <2.5>
  * playlist: implement the command "listplaylists"
  * idle: support event "sticker"
  * support the client-to-client protocol (MPD 0.17)
* Fri Jan 14 2011 detlef@links2linux.de
- new upstream version <2.4>
  * configure.ac, resolver: implement flag --disable-tcp
  * resolver: fix IPv4/IPv6 on the loopback device
  * player: support the command "clearerror"
  * connection: add function mpd_connection_get_server_error_location()
  * settings: expose connection settings
  * iso8601, send: format string workarounds for WIN32
  * Makefile.am: fix doxygen in out-of-tree build
* Sat Sep 25 2010 detlef@links2linux.de
- new upstream version <2.3>
  * get default timeout from environment variable MPD_TIMEOUT
  * fix assertion failures on malformed URI
  * song: support attribute "Range"
  * MixRamp support
  * fix the LIBMPDCLIENT_CHECK_VERSION() macro
* Mon Dec  7 2009 detlef@links2linux.de
- new upstream version <2.1>
  * status: added mpd_status_get_elapsed_ms()
  * sticker: added sticker support
  * song: copy last_modified value in mpd_song_dup()
  * socket, async: use WSAGetLastError() instead of errno on WIN32
  * socket: connect in non-blocking mode
  * socket: set the close-on-exec flag
  * tag: support C++
  * sync: optimistic write, reduce select() calls
  * Makefile.am: use --version-script only with GNU ld
  * added library version compile-time checks
* Wed Oct  7 2009 detlef@links2linux.de
- initial build for PackMan <2.0>
